@@ -6,9 +6,9 @@ use warnings 'all';
 use APR::Table ();
 use Apache2::RequestRec ();
 use Apache2::RequestIO ();
-use Apache2::Directive ();
+#use Apache2::Directive ();
 use Apache2::Connection ();
-use Apache2::SubRequest ();
+#use Apache2::SubRequest ();
 use Apache2::RequestUtil ();
 use Apache2::ASP::HTTPContext ();
 use Apache2::ASP::ModPerl2CGI ();
