@@ -2,42 +2,39 @@
 package Apache2::ASP::UploadHandler;
 
 use strict;
-use base 'Apache2::ASP::Handler';
+use base 'Apache2::ASP::HTTPHandler';
 our $LastUpdate;
 
-use vars qw(
-  %modes
-);
 
 #==============================================================================
 sub upload_start
 {
-  my ($s, $asp, $Upload) = @_;
+  my ($s, $context, $Upload) = @_;
   
   # Store the upload information in the Session for external retrieval:
   $LastUpdate = time();
-  $asp->session->{$_} = $Upload->{$_}
+  $context->session->{$_} = $Upload->{$_}
     foreach keys(%$Upload);
-  $asp->session->save;
+  $context->session->save;
 }# end upload_start()
 
 
 #==============================================================================
 sub upload_end
 {
-  my ($s, $asp, $Upload) = @_;
+  my ($s, $context, $Upload) = @_;
   
   # Clear out the upload data from the Session:
-  delete($asp->session->{$_})
+  delete($context->session->{$_})
     foreach keys(%$Upload);
-  $asp->session->save;
+  $context->session->save;
 }# end upload_end()
 
 
 #==============================================================================
 sub upload_hook
 {
-  my ($s, $asp, $Upload) = @_;
+  my ($s, $context, $Upload) = @_;
   
   # Since this method may be called several times per second, we only
   # want to save the Session state once per second:
@@ -46,9 +43,9 @@ sub upload_hook
   {
     # Store everything in the session except for the data 
     # (since that could be too large to serialize quickly):
-    $asp->session->{$_} = $Upload->{$_}
+    $context->session->{$_} = $Upload->{$_}
       foreach grep { $_ ne 'data' } keys(%$Upload);
-    $asp->session->save;
+    $context->session->save;
     $LastUpdate = time();
   }# end if()
 }# end upload_hook()
@@ -75,21 +72,21 @@ during a file upload.
 
 =head1 OVERRIDABLE METHODS
 
-=head2 upload_start( $self, $asp, $Upload )
+=head2 upload_start( $self, $context, $Upload )
 
 The C<$Upload> argument is an L<Apache2::ASP::UploadHookArgs> object.
 
 Called B<just> before C<upload_hook()> is called for the first time.  If you need to do
 any kind of setup or double-checking, this is the time to do it.
 
-=head2 upload_end( $self, $asp, $Upload )
+=head2 upload_end( $self, $context, $Upload )
 
 The C<$Upload> argument is an L<Apache2::ASP::UploadHookArgs> object.
 
 Called B<just> after C<upload_hook()> is called for the B<last> time.  If you need to do
 any kind of cleanup or redirect the user, this is the time to do it.
 
-=head2 upload_hook( $self, $asp, $Upload )
+=head2 upload_hook( $self, $context, $Upload )
 
 The C<$Upload> argument is an L<Apache2::ASP::UploadHookArgs> object.
 
